@@ -11,7 +11,7 @@ use Alien::Build::Util qw( _perl_config );
 use Carp ();
 
 # ABSTRACT: Package configuration negotiation plugin
-our $VERSION = '2.29'; # VERSION
+our $VERSION = '2.48'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -119,7 +119,7 @@ Alien::Build::Plugin::PkgConfig::Negotiate - Package configuration negotiation p
 
 =head1 VERSION
 
-version 2.29
+version 2.48
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,11 @@ the best C<PkgConfig> plugin depending your platform and environment.
 
 =head2 pkg_name
 
-The package name.
+The package name.  If this is a list reference then .pc files with all those package
+names must be present.  The first name will be the primary and used by default once
+installed.  For the subsequent C<.pc> files you can use the
+L<Alien::Base alt method|Alien::Base/alt> to retrieve the alternate configurations
+once the L<Alien> is installed.
 
 =head2 atleast_version
 
@@ -159,7 +163,7 @@ Alias for C<atleast_version> for backward compatibility.
 
 =head2 pick
 
- my $name = Alien::Build::Plugijn::PkgConfig::Negotiate->pick;
+ my $name = Alien::Build::Plugin::PkgConfig::Negotiate->pick;
 
 Returns the name of the negotiated plugin.
 
@@ -220,7 +224,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -238,6 +242,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
